@@ -166,7 +166,7 @@ class APITestCase(unittest.TestCase):
         self.assertEqual(pep8style.options.filename, ['*.py'])
         self.assertEqual(pep8style.options.format, 'default')
         self.assertEqual(pep8style.options.select, ())
-        self.assertEqual(pep8style.options.ignore, ('E226', 'E24'))
+        self.assertEqual(pep8style.options.ignore, ('E226', 'E24', 'W504'))
         self.assertEqual(pep8style.options.max_line_length, 79)
 
     def test_styleguide_ignore_code(self):
@@ -182,7 +182,7 @@ class APITestCase(unittest.TestCase):
         self.assertEqual(options.select, ())
         self.assertEqual(
             options.ignore,
-            ('E121', 'E123', 'E126', 'E226', 'E24', 'E704', 'W503')
+            ('E121', 'E123', 'E126', 'E226', 'E24', 'E704', 'W503', 'W504')
         )
 
         options = parse_argv('--doctest').options
